"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Uri = android.net.Uri;
var telemetry_1 = require("./util/telemetry");
var Auth0 = (function () {
    function Auth0(clientId, domain, configurationDomain) {
        this.clientId = clientId;
        this.domainUrl = this.ensureValidUrl(domain);
        if (this.domainUrl == null) {
            throw new java.lang.IllegalArgumentException("Invalid domain url: '" + domain + "'");
        }
        this.configurationUrl = this.resolveConfiguration(configurationDomain, this.domainUrl);
        this.telemetry = new telemetry_1.Telemetry('Auth0.NativeScript', '0.0.0');
    }
    Auth0.prototype.getClientId = function () {
        return this.clientId;
    };
    Auth0.prototype.getDomainUrl = function () {
        return this.domainUrl.toString();
    };
    Auth0.prototype.getConfigurationUrl = function () {
        return this.configurationUrl.toString();
    };
    Auth0.prototype.getAuthorizeUrl = function () {
        return this.domainUrl.buildUpon()
            .appendEncodedPath("authorize")
            .build()
            .toString();
    };
    Auth0.prototype.getTelemetry = function () {
        return this.telemetry;
    };
    Auth0.prototype.setTelemetry = function (telemetry) {
        this.telemetry = telemetry;
    };
    Auth0.prototype.doNotSendTelemetry = function () {
        this.telemetry = null;
    };
    Auth0.prototype.isLoggingEnabled = function () {
        return this.loggingEnabled;
    };
    Auth0.prototype.setLoggingEnabled = function (enabled) {
        this.loggingEnabled = enabled;
    };
    Auth0.prototype.isTLS12Enforced = function () {
        return this.tls12Enforced;
    };
    Auth0.prototype.setTLS12Enforced = function (enforced) {
        this.tls12Enforced = enforced;
    };
    Auth0.prototype.resolveConfiguration = function (configurationDomain, domainUrl) {
        var url = this.ensureValidUrl(configurationDomain);
        if (url == null) {
            var host = domainUrl.getHost();
            if (host.endsWith(Auth0.DOT_AUTH0_DOT_COM)) {
                var parts = host.split('.');
                if (parts.length > 3) {
                    url = Uri.parse("https://cdn." + parts[parts.length - 3] + Auth0.DOT_AUTH0_DOT_COM);
                }
                else {
                    url = Uri.parse(Auth0.AUTH0_US_CDN_URL);
                }
            }
            else {
                url = domainUrl;
            }
        }
        return url;
    };
    Auth0.prototype.ensureValidUrl = function (url) {
        if (url == null) {
            return null;
        }
        var safeUrl = url.startsWith("http") ? url : "https://" + url;
        return Uri.parse(safeUrl);
    };
    Auth0.getResourceFromContext = function (context, resName) {
        var stringRes = context.getResources().getIdentifier(resName, "string", context.getPackageName());
        if (stringRes === 0) {
            throw new java.lang.IllegalArgumentException("The 'R.string." + resName + "' value it's not defined in your project's resources file.");
        }
        return context.getString(stringRes);
    };
    Auth0.AUTH0_US_CDN_URL = "https://cdn.auth0.com";
    Auth0.DOT_AUTH0_DOT_COM = ".auth0.com";
    return Auth0;
}());
exports.Auth0 = Auth0;
//# sourceMappingURL=auth0.js.map