"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ParameterBuilder = (function () {
    function ParameterBuilder(parameters) {
        if (parameters == null) {
            throw new java.lang.IllegalArgumentException("Must provide non-null parameters");
        }
        this.parameters = Object.assign({}, parameters);
    }
    ParameterBuilder.prototype.setClientId = function (clientId) {
        return this.setParameter(ParameterBuilder.CLIENT_ID_KEY, clientId);
    };
    ParameterBuilder.prototype.setGrantType = function (grantType) {
        return this.setParameter(ParameterBuilder.GRANT_TYPE_KEY, grantType);
    };
    ParameterBuilder.prototype.setConnection = function (connection) {
        return this.setParameter(ParameterBuilder.CONNECTION_KEY, connection);
    };
    ParameterBuilder.prototype.setRealm = function (realm) {
        return this.setParameter(ParameterBuilder.REALM_KEY, realm);
    };
    ParameterBuilder.prototype.setScope = function (scope) {
        return this.setParameter(ParameterBuilder.SCOPE_KEY, scope);
    };
    ParameterBuilder.prototype.setAudience = function (audience) {
        return this.setParameter(ParameterBuilder.AUDIENCE_KEY, audience);
    };
    ParameterBuilder.prototype.setAccessToken = function (accessToken) {
        return this.setParameter(ParameterBuilder.ACCESS_TOKEN_KEY, accessToken);
    };
    ParameterBuilder.prototype.setRefreshToken = function (refreshToken) {
        return this.setParameter(ParameterBuilder.REFRESH_TOKEN_KEY, refreshToken);
    };
    ParameterBuilder.prototype.setParameter = function (key, value) {
        if (value == null) {
            delete this.parameters[key];
        }
        else {
            this.parameters[key] = value;
        }
        return this;
    };
    ParameterBuilder.prototype.addAll = function (parameters) {
        if (parameters != null) {
            for (var k in parameters) {
                if (parameters[k] != null) {
                    this.parameters[k] = parameters[k];
                }
            }
        }
        return this;
    };
    ParameterBuilder.prototype.clearAll = function () {
        this.parameters.clear();
        return this;
    };
    ParameterBuilder.prototype.asDictionary = function () {
        return Object.assign({}, this.parameters);
    };
    ParameterBuilder.newAuthenticationBuilder = function () {
        return ParameterBuilder
            .newBuilder()
            .setScope(ParameterBuilder.SCOPE_OPENID);
    };
    ParameterBuilder.newBuilder = function (parameters) {
        return new ParameterBuilder(parameters || {});
    };
    ParameterBuilder.GRANT_TYPE_REFRESH_TOKEN = "refresh_token";
    ParameterBuilder.GRANT_TYPE_PASSWORD = "password";
    ParameterBuilder.GRANT_TYPE_PASSWORD_REALM = "http://auth0.com/oauth/grant-type/password-realm";
    ParameterBuilder.GRANT_TYPE_AUTHORIZATION_CODE = "authorization_code";
    ParameterBuilder.GRANT_TYPE_MFA_OTP = "http://auth0.com/oauth/grant-type/mfa-otp";
    ParameterBuilder.SCOPE_OPENID = "openid";
    ParameterBuilder.SCOPE_OFFLINE_ACCESS = "openid offline_access";
    ParameterBuilder.ID_TOKEN_KEY = "id_token";
    ParameterBuilder.SCOPE_KEY = "scope";
    ParameterBuilder.REFRESH_TOKEN_KEY = "refresh_token";
    ParameterBuilder.CONNECTION_KEY = "connection";
    ParameterBuilder.REALM_KEY = "realm";
    ParameterBuilder.ACCESS_TOKEN_KEY = "access_token";
    ParameterBuilder.CLIENT_ID_KEY = "client_id";
    ParameterBuilder.GRANT_TYPE_KEY = "grant_type";
    ParameterBuilder.AUDIENCE_KEY = "audience";
    return ParameterBuilder;
}());
exports.ParameterBuilder = ParameterBuilder;
//# sourceMappingURL=parameterBuilder.js.map