"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var PasswordStrengthErrorParser = (function () {
    function PasswordStrengthErrorParser(descriptionMap) {
        var rules = descriptionMap[PasswordStrengthErrorParser.KEY_RULES];
        this.parseRules(rules);
    }
    PasswordStrengthErrorParser.prototype.getDescription = function () {
        return this.description;
    };
    PasswordStrengthErrorParser.prototype.parseRules = function (rules) {
        var items = [];
        for (var _i = 0, rules_1 = rules; _i < rules_1.length; _i++) {
            var rule = rules_1[_i];
            var isVerified = rule[PasswordStrengthErrorParser.KEY_VERIFIED];
            if (isVerified) {
                continue;
            }
            var code = rule[PasswordStrengthErrorParser.KEY_CODE];
            switch (code) {
                case PasswordStrengthErrorParser.RULE_TYPE_LENGTH_AT_LEAST:
                    items.push(this.asLengthAtLeast(rule));
                    break;
                case PasswordStrengthErrorParser.RULE_TYPE_IDENTICAL_CHARS:
                    items.push(this.asIdenticalChars(rule));
                    break;
                case PasswordStrengthErrorParser.RULE_TYPE_CONTAINS_AT_LEAST:
                case PasswordStrengthErrorParser.RULE_TYPE_SHOULD_CONTAIN:
                    items.push(this.asContainsCharset(rule));
                    break;
            }
        }
        this.description = items.join('; ');
    };
    PasswordStrengthErrorParser.prototype.asLengthAtLeast = function (rule) {
        var length = rule[PasswordStrengthErrorParser.KEY_FORMAT];
        var message = rule[PasswordStrengthErrorParser.KEY_MESSAGE];
        return java.lang.String.format(message, [length[0]]);
    };
    PasswordStrengthErrorParser.prototype.asContainsCharset = function (rule) {
        var itemsList = rule[PasswordStrengthErrorParser.KEY_ITEMS];
        var items = [];
        for (var _i = 0, itemsList_1 = itemsList; _i < itemsList_1.length; _i++) {
            var i = itemsList_1[_i];
            items.push(i[PasswordStrengthErrorParser.KEY_MESSAGE]);
        }
        var requiredItems = items.join(', ');
        var message = rule[PasswordStrengthErrorParser.KEY_MESSAGE];
        if (rule.containsKey(PasswordStrengthErrorParser.KEY_FORMAT)) {
            var quantity = rule[PasswordStrengthErrorParser.KEY_FORMAT];
            message = java.lang.String.format(message, [quantity[0], quantity[1]]);
        }
        return java.lang.String.format(message, [requiredItems]);
    };
    PasswordStrengthErrorParser.prototype.asIdenticalChars = function (rule) {
        var example = rule[PasswordStrengthErrorParser.KEY_FORMAT];
        var count = example[0];
        var message = rule[PasswordStrengthErrorParser.KEY_MESSAGE];
        return java.lang.String.format(message, [count, example[1]]);
    };
    PasswordStrengthErrorParser.RULE_TYPE_LENGTH_AT_LEAST = "lengthAtLeast";
    PasswordStrengthErrorParser.RULE_TYPE_CONTAINS_AT_LEAST = "containsAtLeast";
    PasswordStrengthErrorParser.RULE_TYPE_SHOULD_CONTAIN = "shouldContain";
    PasswordStrengthErrorParser.RULE_TYPE_IDENTICAL_CHARS = "identicalChars";
    PasswordStrengthErrorParser.KEY_RULES = "rules";
    PasswordStrengthErrorParser.KEY_CODE = "code";
    PasswordStrengthErrorParser.KEY_VERIFIED = "verified";
    PasswordStrengthErrorParser.KEY_FORMAT = "format";
    PasswordStrengthErrorParser.KEY_ITEMS = "items";
    PasswordStrengthErrorParser.KEY_MESSAGE = "message";
    return PasswordStrengthErrorParser;
}());
exports.PasswordStrengthErrorParser = PasswordStrengthErrorParser;
//# sourceMappingURL=passwordStrengthErrorParser.js.map