"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Log = android.util.Log;
var algorithmHelper_1 = require("./algorithmHelper");
var PKCE = (function () {
    function PKCE(apiClient, redirectUri, algorithmHelper) {
        if (algorithmHelper === void 0) { algorithmHelper = new algorithmHelper_1.AlgorithmHelper(); }
        this.apiClient = apiClient;
        this.redirectUri = redirectUri;
        this.codeVerifier = algorithmHelper.generateCodeVerifier();
        this.codeChallenge = algorithmHelper.generateCodeChallenge(this.codeVerifier);
    }
    PKCE.prototype.getCodeChallenge = function () {
        return this.codeChallenge;
    };
    PKCE.prototype.getToken = function (authorizationCode, callback) {
        this.apiClient.token(authorizationCode, this.redirectUri)
            .setCodeVerifier(this.codeVerifier)
            .start({
            onSuccess: function (payload) {
                callback.onSuccess(payload);
            },
            onFailure: function (error) {
                if ("Unauthorized" === error.getDescription()) {
                    Log.e(PKCE.TAG, "Please go to 'https://manage.auth0.com/#/applications/" + this.apiClient.getClientId() + "/settings' and set 'Client Type' to 'Native' to enable PKCE.");
                }
                callback.onFailure(error);
            }
        });
    };
    PKCE.isAvailable = function (algorithmHelper) {
        if (algorithmHelper === void 0) { algorithmHelper = new algorithmHelper_1.AlgorithmHelper(); }
        try {
            var input = algorithmHelper.getASCIIBytes("test");
            algorithmHelper.getSHA256(input);
        }
        catch (ignored) {
            return false;
        }
        return true;
    };
    PKCE.TAG = 'PKCE';
    return PKCE;
}());
exports.PKCE = PKCE;
//# sourceMappingURL=pkce.js.map