"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Locale = java.util.Locale;
var telemetry_1 = require("../../util/telemetry");
var voidRequest_1 = require("./voidRequest");
var credentials_1 = require("../../../common/credentials");
var simpleRequest_1 = require("./simpleRequest");
var baseAuthenticationRequest_1 = require("./baseAuthenticationRequest");
var RequestFactory = (function () {
    function RequestFactory(bearerToken) {
        this.headers = {};
        this.headers[RequestFactory.ACCEPT_LANGUAGE_HEADER] = RequestFactory.getDefaultLocale();
        if (bearerToken != null) {
            this.headers[RequestFactory.AUTHORIZATION_HEADER] = "Bearer " + bearerToken;
        }
    }
    RequestFactory.prototype.setClientInfo = function (clientInfo) {
        this.headers[RequestFactory.CLIENT_INFO_HEADER] = clientInfo;
    };
    RequestFactory.prototype.setUserAgent = function (userAgent) {
        this.headers[RequestFactory.USER_AGENT_HEADER] = userAgent;
    };
    RequestFactory.prototype.authenticationPOST = function (url) {
        var request = this.createAuthenticationRequest(url, "POST");
        this.addMetrics(request);
        return request;
    };
    RequestFactory.prototype.POST = function () {
        if (arguments.length > 2) {
            var request = this.createSimpleRequest(arguments[0], "POST", arguments[1], arguments[2]);
            this.addMetrics(request);
            return request;
        }
        else {
            var request = this.createVoidRequest(arguments[0], "POST", arguments[1]);
            this.addMetrics(request);
            return request;
        }
    };
    RequestFactory.prototype.PATCH = function (url, adapter, errorBuilder) {
        var request = this.createSimpleRequest(url, "PATCH", adapter, errorBuilder);
        this.addMetrics(request);
        return request;
    };
    RequestFactory.prototype.DELETE = function (url, adapter, errorBuilder) {
        var request = this.createSimpleRequest(url, "DELETE", adapter, errorBuilder);
        this.addMetrics(request);
        return request;
    };
    RequestFactory.prototype.GET = function (url, adapter, errorBuilder) {
        var request = this.createSimpleRequest(url, "GET", adapter, errorBuilder);
        this.addMetrics(request);
        return request;
    };
    RequestFactory.prototype.addMetrics = function (request) {
        for (var entry in this.headers) {
            request.addHeader(entry, this.headers[entry]);
        }
    };
    RequestFactory.prototype.createSimpleRequest = function (url, method, adapter, errorBuilder) {
        return new simpleRequest_1.SimpleRequest(url, method, adapter, errorBuilder);
    };
    RequestFactory.prototype.createAuthenticationRequest = function (url, method) {
        return new baseAuthenticationRequest_1.BaseAuthenticationRequest(url, method, credentials_1.Credentials);
    };
    RequestFactory.prototype.createVoidRequest = function (url, method, errorBuilder) {
        return new voidRequest_1.VoidRequest(url, method, errorBuilder);
    };
    RequestFactory.prototype.getHeaders = function () {
        return this.headers;
    };
    RequestFactory.getDefaultLocale = function () {
        var language = Locale.getDefault().toString();
        return language !== '' ? language : RequestFactory.DEFAULT_LOCALE_IF_MISSING;
    };
    RequestFactory.DEFAULT_LOCALE_IF_MISSING = "en_US";
    RequestFactory.AUTHORIZATION_HEADER = "Authorization";
    RequestFactory.USER_AGENT_HEADER = "User-Agent";
    RequestFactory.ACCEPT_LANGUAGE_HEADER = "Accept-Language";
    RequestFactory.CLIENT_INFO_HEADER = telemetry_1.Telemetry.HEADER_NAME;
    return RequestFactory;
}());
exports.RequestFactory = RequestFactory;
//# sourceMappingURL=requestFactory.js.map