"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var application = require("tns-core-modules/application/application");
var auth0_common_1 = require("./auth0-common");
exports.ResponseType = auth0_common_1.ResponseType;
exports.WebAuthException = auth0_common_1.WebAuthException;
var authenticationAPIClient_1 = require("./android/authentication/authenticationAPIClient");
var webAuthProvider_1 = require("./android/provider/webAuthProvider");
var auth0_1 = require("./android/auth0");
var credentials_1 = require("./common/credentials");
exports.Credentials = credentials_1.Credentials;
var userInfo_1 = require("./common/userInfo");
exports.UserInfo = userInfo_1.UserInfo;
var Auth0 = (function (_super) {
    __extends(Auth0, _super);
    function Auth0(clientId, domain) {
        var _this = _super.call(this, clientId, domain) || this;
        _this.account = new auth0_1.Auth0(clientId, domain);
        _this.authenticationApi = new authenticationAPIClient_1.AuthenticationAPIClient(_this.account);
        return _this;
    }
    Auth0.prototype.webAuthentication = function (options) {
        var webAuth = new webAuthProvider_1.WebAuthProvider(this.account);
        if (options.audience != null) {
            webAuth.withAudience(options.audience);
        }
        if (options.connection != null) {
            webAuth.withConnection(options.connection);
        }
        if (options.nonce != null) {
            webAuth.withNonce(options.nonce);
        }
        if (options.responseType != null) {
            webAuth.withResponseType(options.responseType);
        }
        if (options.scheme != null) {
            webAuth.withScheme(options.scheme);
        }
        if (options.scope != null) {
            webAuth.withScope(options.scope);
        }
        if (options.state != null) {
            webAuth.withState(options.state);
        }
        if (options.parameters != null) {
            webAuth.withParameters(options.parameters);
        }
        return new Promise(function (resolve, reject) {
            try {
                var activity = application.android.foregroundActivity == null ? application.android.startActivity : application.android.foregroundActivity;
                webAuth.start(activity, {
                    onFailure: function (dialogOrException) {
                        if (dialogOrException instanceof android.app.Dialog) {
                            reject(new auth0_common_1.WebAuthException(dialogOrException.toString()));
                        }
                        else {
                            reject(new auth0_common_1.WebAuthException(dialogOrException.getDescription()));
                        }
                    },
                    onSuccess: function (credentials) {
                        resolve(credentials);
                    }
                });
            }
            catch (e) {
                reject(e);
            }
        });
    };
    Auth0.prototype.renewCredentials = function (refreshToken) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            try {
                _this.authenticationApi
                    .renewAuth(refreshToken)
                    .start({
                    onFailure: function (error) {
                        reject(error);
                    },
                    onSuccess: function (credentials) {
                        resolve(credentials);
                    }
                });
            }
            catch (e) {
                reject(e);
            }
        });
    };
    Auth0.prototype.revokeRefreshToken = function (refreshToken) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            try {
                _this.authenticationApi
                    .revokeToken(refreshToken)
                    .start({
                    onFailure: function (error) {
                        reject(error);
                    },
                    onSuccess: function () {
                        resolve();
                    }
                });
            }
            catch (e) {
                reject(e);
            }
        });
    };
    Auth0.prototype.getUserInfo = function (accessToken) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            try {
                _this.authenticationApi
                    .userInfo(accessToken)
                    .start({
                    onFailure: function (error) {
                        reject(error);
                    },
                    onSuccess: function (userInfo) {
                        resolve(userInfo);
                    }
                });
            }
            catch (e) {
                reject(e);
            }
        });
    };
    return Auth0;
}(auth0_common_1.Auth0Common));
exports.Auth0 = Auth0;
//# sourceMappingURL=auth0.android.js.map