"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var auth0_common_1 = require("./auth0-common");
exports.ResponseType = auth0_common_1.ResponseType;
exports.WebAuthException = auth0_common_1.WebAuthException;
var auth0Authentication_1 = require("./ios/auth0Authentication");
var safariWebAuth_1 = require("./ios/safariWebAuth");
var responseType_1 = require("./ios/responseType");
var utils_1 = require("./ios/utils");
var credentials_1 = require("./common/credentials");
exports.Credentials = credentials_1.Credentials;
var userInfo_1 = require("./common/userInfo");
exports.UserInfo = userInfo_1.UserInfo;
var webAuth_1 = require("./ios/webAuth");
exports.resumeAuth = webAuth_1.resumeAuth;
var Auth0 = (function (_super) {
    __extends(Auth0, _super);
    function Auth0(clientId, domain) {
        var _this = _super.call(this, clientId, domain) || this;
        _this.authenticationApi = new auth0Authentication_1.Auth0Authentication(_this.clientId, utils_1.a0_url(_this.domain));
        return _this;
    }
    Auth0.prototype.webAuthentication = function (options) {
        var auth = safariWebAuth_1.SafariWebAuth.init(this.clientId, utils_1.a0_url(this.domain));
        if (options.audience != null) {
            auth.setAudience(options.audience);
        }
        if (options.connection != null) {
            auth.setConnection(options.connection);
        }
        if (options.nonce != null) {
            auth.setNonce(options.nonce);
        }
        if (options.responseType != null) {
            switch (options.responseType) {
                case auth0_common_1.ResponseType.CODE:
                    auth.setResponseType([responseType_1.ResponseType.code]);
                    break;
                case auth0_common_1.ResponseType.TOKEN:
                    auth.setResponseType([responseType_1.ResponseType.token]);
                    break;
                case auth0_common_1.ResponseType.ID_TOKEN:
                    auth.setResponseType([responseType_1.ResponseType.idToken]);
                    break;
            }
        }
        if (options.scope != null) {
            auth.setScope(options.scope);
        }
        if (options.state != null) {
            auth.setState(options.state);
        }
        if (options.parameters != null) {
            auth.setParameters(options.parameters);
        }
        return new Promise(function (resolve, reject) {
            try {
                auth.start(function (result) {
                    if (result.failure != null) {
                        reject(new auth0_common_1.WebAuthException(result.failure.message));
                    }
                    else {
                        var credentials = result.success;
                        resolve(credentials);
                    }
                });
            }
            catch (e) {
                reject(e);
            }
        });
    };
    Auth0.prototype.renewCredentials = function (refreshToken) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            try {
                _this.authenticationApi
                    .renew(refreshToken)
                    .start(function (result) {
                    if (result.failure != null) {
                        reject(result.failure);
                    }
                    else {
                        resolve(result.success);
                    }
                });
            }
            catch (e) {
                reject(e);
            }
        });
    };
    Auth0.prototype.revokeRefreshToken = function (refreshToken) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            try {
                _this.authenticationApi
                    .revoke(refreshToken)
                    .start(function (result) {
                    if (result.failure != null) {
                        reject(result.failure);
                    }
                    else {
                        resolve();
                    }
                });
            }
            catch (e) {
                reject(e);
            }
        });
    };
    Auth0.prototype.getUserInfo = function (accessToken) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            try {
                _this.authenticationApi
                    .userInfo(accessToken)
                    .start(function (result) {
                    if (result.failure != null) {
                        reject(result.failure);
                    }
                    else {
                        resolve(result.success);
                    }
                });
            }
            catch (e) {
                reject(e);
            }
        });
    };
    return Auth0;
}(auth0_common_1.Auth0Common));
exports.Auth0 = Auth0;
//# sourceMappingURL=auth0.ios.js.map