"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var authenticationError_1 = require("./authenticationError");
var webAuthError_1 = require("./webAuthError");
var AuthSession = (function () {
    function AuthSession(redirectURL, state, handler, finish, logger) {
        if (state === void 0) { state = undefined; }
        this.redirectURL = redirectURL;
        this.state = state;
        this.finish = finish;
        this.handler = handler;
        this.logger = logger;
    }
    AuthSession.prototype.resume = function (url, options) {
        if (options === void 0) { options = NSDictionary.alloc(); }
        if (this.logger != null) {
            this.logger.trace(url, "iOS Safari");
        }
        var hasPrefix = url.absoluteString.toLowerCase().startsWith(this.redirectURL.absoluteString.toLowerCase());
        if (hasPrefix === false) {
            return false;
        }
        var components = new NSURLComponents({ URL: url, resolvingAgainstBaseURL: true });
        if (components == null) {
            this.finish({
                failure: new authenticationError_1.AuthenticationError(url.absoluteString, 200)
            });
            return false;
        }
        var items = this.handler.values(components);
        var has = this.has(this.state, items);
        if (has === false) {
            return false;
        }
        if (items["error"] != null) {
            this.finish({
                failure: new authenticationError_1.AuthenticationError(items, 0)
            });
        }
        else {
            this.handler.credentials(items, this.finish);
        }
        return true;
    };
    AuthSession.prototype.cancel = function () {
        this.finish({
            failure: webAuthError_1.WebAuthError.userCancelled
        });
    };
    AuthSession.prototype.has = function (state, items) {
        return state === null || items["state"] === state;
    };
    return AuthSession;
}());
exports.AuthSession = AuthSession;
//# sourceMappingURL=authSession.js.map