"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var authenticationError_1 = require("./authenticationError");
var http_1 = require("tns-core-modules/http/http");
var auth0Error_1 = require("./auth0Error");
function plainJson(response, callback) {
    try {
        var dictionary = response.result();
        if (dictionary != null) {
            callback({
                success: dictionary
            });
        }
        else {
            callback({
                failure: new authenticationError_1.AuthenticationError(response.data.toString(http_1.HttpResponseEncoding.UTF8))
            });
        }
    }
    catch (error) {
        callback({
            failure: error
        });
    }
}
exports.plainJson = plainJson;
function authenticationObject(TClass) {
    return function (response, callback) {
        try {
            var dictionary = response.result();
            var object = (dictionary != null) ? TClass.initWithJson(dictionary) : undefined;
            if (object != null) {
                callback({
                    success: object
                });
            }
            else {
                callback({
                    failure: new authenticationError_1.AuthenticationError(response.data.toString(http_1.HttpResponseEncoding.UTF8))
                });
            }
        }
        catch (error) {
            callback({
                failure: error
            });
        }
    };
}
exports.authenticationObject = authenticationObject;
function noBody(response, callback) {
    try {
        var _ = response.result();
        callback({
            success: true
        });
    }
    catch (error) {
        if (error instanceof auth0Error_1.Auth0Error && error.code === auth0Error_1.emptyBodyError) {
            callback({
                success: true
            });
        }
        else {
            callback({
                failure: error
            });
        }
    }
}
exports.noBody = noBody;
//# sourceMappingURL=handlers.js.map