"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_1 = require("tns-core-modules/http/http");
var DefaultOutput = (function () {
    function DefaultOutput() {
    }
    DefaultOutput.prototype.log = function (message) { console.log(message); };
    DefaultOutput.prototype.newLine = function () { console.log(''); };
    return DefaultOutput;
}());
var DefaultLogger = (function () {
    function DefaultLogger(output) {
        if (output === void 0) { output = new DefaultOutput(); }
        this.output = output;
    }
    DefaultLogger.prototype.trace = function () {
        if (arguments[0] instanceof NSURL) {
            this.traceUrl(arguments[0], arguments[1]);
        }
        else if (arguments[0].url != null) {
            this.traceRequest(arguments[0]);
        }
        {
            this.traceResponse(arguments[0]);
        }
    };
    DefaultLogger.prototype.traceRequest = function (request) {
        var method = request.method;
        var url = request.url;
        if (method == null || url == null) {
            return;
        }
        this.output.log(method + " " + url + " HTTP/1.1");
        var headerFields = request.headers;
        if (headerFields != null) {
            for (var key in headerFields) {
                this.output.log(key + ": " + headerFields[key]);
            }
        }
        var data = request.content;
        if (data != null) {
            this.output.newLine();
            this.output.log(String(data));
        }
        this.output.newLine();
    };
    DefaultLogger.prototype.traceResponse = function (response) {
        this.output.log("HTTP/1.1 " + response.statusCode);
        for (var key in response.headers) {
            this.output.log(key + ": " + response.headers[key]);
        }
        if (response.content.toString(http_1.HttpResponseEncoding.UTF8) != null) {
            var _string = response.content.toString(http_1.HttpResponseEncoding.UTF8);
            if (_string != null) {
                this.output.newLine();
                this.output.log(_string);
            }
        }
        this.output.newLine();
    };
    DefaultLogger.prototype.traceUrl = function (url, source) {
        this.output.log((source || 'URL') + ": " + url.absoluteString);
    };
    return DefaultLogger;
}());
exports.DefaultLogger = DefaultLogger;
//# sourceMappingURL=logger.js.map