"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_1 = require("tns-core-modules/http/http");
var response_1 = require("./response");
var Request = (function () {
    function Request(url, method, handle, payload, headers, logger, telemetry, EClass) {
        if (payload === void 0) { payload = {}; }
        if (headers === void 0) { headers = {}; }
        this.url = url;
        this.method = method;
        this.handle = handle;
        this.payload = payload;
        this.headers = headers;
        this.logger = logger;
        this.telemetry = telemetry;
        this.EClass = EClass;
    }
    Object.defineProperty(Request.prototype, "request", {
        get: function () {
            var request = {
                url: this.url.absoluteString,
                method: this.method,
                headers: {
                    'Content-Type': 'application/json'
                },
            };
            if (Object.keys(this.payload).length > 0) {
                request.content = JSON.stringify(this.payload);
            }
            for (var key in this.headers) {
                request.headers[key] = this.headers[key];
            }
            this.telemetry.addTelemetryHeader(request);
            return request;
        },
        enumerable: true,
        configurable: true
    });
    Request.prototype.start = function (callback) {
        var _this = this;
        var handler = this.handle;
        var request = this.request;
        var logger = this.logger;
        if (logger != null) {
            logger.trace(request);
        }
        http_1.request(request).then(function (response) {
            if (logger != null) {
                logger.trace(response);
            }
            handler(new response_1.Response(response.content, request, response, undefined, _this.EClass), callback);
        }).catch(function (error) {
            handler(new response_1.Response(undefined, request, undefined, error, _this.EClass), callback);
        });
    };
    return Request;
}());
exports.Request = Request;
var ConcatRequest = (function () {
    function ConcatRequest() {
    }
    ConcatRequest.prototype.start = function (callback) {
        var second = this.second;
        this.first.start(function (result) {
            if (result.failure) {
                callback({
                    failure: result.failure
                });
            }
            else if (result.success) {
                second.start(callback);
            }
        });
    };
    return ConcatRequest;
}());
exports.ConcatRequest = ConcatRequest;
//# sourceMappingURL=request.js.map