"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
var Telemetry = (function () {
    function Telemetry() {
        this.enabled = true;
        this.info = Telemetry.generateValue();
    }
    Object.defineProperty(Telemetry.prototype, "value", {
        get: function () {
            return this.enabled ? this.info : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Telemetry.prototype.wrapped = function (name, version) {
        var _a;
        var info = Telemetry.versionInformation();
        var wrapped = (_a = {},
            _a[Telemetry.NameKey] = name,
            _a[Telemetry.VersionKey] = version,
            _a[Telemetry.WrappedVersion] = info[Telemetry.VersionKey] || Telemetry.NoVersion,
            _a);
        this.info = Telemetry.generateValue(wrapped);
    };
    Telemetry.prototype.addTelemetryHeader = function (request) {
        var value = this.value;
        if (value != null) {
            request.headers['Auth0-Client'] = value;
        }
        else {
            request.headers['Auth0-Client'] = null;
        }
    };
    Telemetry.prototype.queryItemsWithTelemetry = function (queryItems) {
        var items = queryItems;
        var value = this.value;
        if (value != null) {
            items.push(new NSURLQueryItem({ name: 'auth0Client', value: value }));
        }
        return items;
    };
    Telemetry.versionInformation = function () {
        var _a;
        var dict = (_a = {},
            _a[Telemetry.NameKey] = Telemetry.LibraryName,
            _a[Telemetry.VersionKey] = Telemetry.NoVersion,
            _a['swift-version'] = '3.2',
            _a);
        return dict;
    };
    Telemetry.generateValue = function (info) {
        if (info === void 0) { info = Telemetry.versionInformation(); }
        var data = JSON.stringify(info);
        return utils_1.a0_encodeBase64URLSafe(data);
    };
    Telemetry.NameKey = 'name';
    Telemetry.VersionKey = 'version';
    Telemetry.WrappedVersion = 'lib_version';
    Telemetry.NoVersion = '0.0.0';
    Telemetry.LibraryName = 'Auth0.NativeScript';
    return Telemetry;
}());
exports.Telemetry = Telemetry;
var TrackableExtension = (function () {
    function TrackableExtension() {
    }
    TrackableExtension.tracking = function (trackable, enabled) {
        trackable.telemetry.enabled = enabled;
    };
    TrackableExtension.using = function (trackable, name, version) {
        trackable.telemetry.wrapped(name, version);
    };
    return TrackableExtension;
}());
exports.TrackableExtension = TrackableExtension;
//# sourceMappingURL=telemetry.js.map